import { TestRequest } from '@angular/common/http/testing';
import { SlTestRequest } from './sl-test-request';
export declare type HttpMethod = 'DELETE' | 'GET' | 'POST' | 'PUT';
export declare type HttpBody = Parameters<TestRequest['flush']>[0];
interface RequestOptions {
    params?: Record<string, string>;
    headers?: Record<string, string>;
}
/**
 * This convenience method is similar to [HttpTestingController.expectOne()]{@linkcode https://angular.io/api/common/http/testing/HttpTestingController}, with extra features. The returned request object will automatically trigger change detection when you flush a response, just like in production.
 *
 * This method is opinionated in that you must specify all aspects of the request to match. E.g. if the request specifies headers, you must also specify them in the arguments to this method.
 *
 * This method only works when you are using an {@linkcode AngularContext}.
 *
 * ```ts
 * const ctx = new AngularContext();
 * ctx.run(() => {
 *   ctx
 *     .inject(HttpClient)
 *     .get('http://example.com', { params: { key: 'value' } })
 *     .subscribe();
 *   const request = expectRequest<string>('GET', 'http://example.com', {
 *     params: { key: 'value' },
 *   });
 *   request.flush('my response body');
 * });
 * ```
 */
export declare function expectRequest<ResponseBody extends HttpBody>(method: HttpMethod, url: string, options?: RequestOptions & {
    body?: HttpBody;
}): SlTestRequest<ResponseBody>;
export {};
